<template>
  <el-dialog
    width="40%"
    title="新增BOM节点"
    top="15vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    :close-on-click-modal="false"
    class="struct-form-dialog"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="structForm"
      label-width="120px"
      class="l-mes"
    >
      <el-form-item label="零件" prop="partId">
        <el-input v-model="partStr" placeholder="" readonly>
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openPartDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
      <el-form-item label="消耗工序" prop="operationId">
        <el-input v-model="dataForm.operationName" placeholder="" readonly>
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openOperationDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
      <el-form-item label="单位产出所需数量" prop="qpa">
        <el-input v-model="dataForm.qpa" placeholder=""></el-input>
      </el-form-item>
      <el-form-item label="盘数(盘)" prop="discNum">
        <el-input v-model="dataForm.discNum" placeholder=""></el-input>
      </el-form-item>
    </el-form>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
    <!-- 选择弹框 -->
    <part-dialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPart"
    />
    <operation-dialog
      :currshowlist.sync="showOperation"
      @listenToOperationEvent="selectOperation"
    />
  </el-dialog>
</template>
<script>
import { addMoBomCompont } from '@/api/plan/manufacturingorder'
import PartDialog from '@/views/common/part'
import OperationDialog from '@/views/common/operation'
import { validateSixDecimalNotNull } from '@/util/validate'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    selectedStruct: {
      type: Object,
      default: () => {
        return {}
      }
    },
    moId: {
      type: Number,
      default: 0
    }
  },
  components: {
    PartDialog,
    OperationDialog
  },
  data() {
    return {
      innerVisible: false,
      dataForm: {
        partName: null,
        partNo: null,
        partId: null,
        qpa: null,
        discNum: null,
        unit: null,
        parent: null,
        operationId: null,
        operationName: null,
        operationNo: null
      },
      dataRule: {
        partId: [{ required: true, message: '零件不能为空', trigger: 'blur' }],
        operationId: [
          { required: true, message: '工序不能为空', trigger: 'blur' }
        ],
        qpa: [
          {
            required: true,
            message: '单位产出所需数量不能为空',
            trigger: 'blur'
          },
          { validator: validateSixDecimalNotNull, trigger: 'blur' }
        ],
        discNum: [
          {
            required: true,
            message: '盘数(盘)不能为空',
            trigger: 'blur'
          },
          { validator: validateSixDecimalNotNull, trigger: 'blur' }
        ]
      },
      showPart: false,
      showOperation: false
    }
  },
  computed: {
    partStr: function() {
      return this.dataForm.partId
        ? this.dataForm.partName + '  ' + this.dataForm.partNo
        : ''
    }
  },
  methods: {
    saveSelectRow() {
      this.$refs.structForm.validate((valid) => {
        if (valid) {
          this.dataForm.parent = this.selectedStruct.id
          this.dataForm.planManufacturingOrderId = this.moId
          addMoBomCompont(this.dataForm)
            .then((response) => {
              const resData = response.data
              if (resData.code === 0) {
                this.innerVisible = false
                this.$message.success('新增节点成功')
                this.$emit('refreshBom', resData.data)
              } else {
                this.$message.error('新增节点失败')
              }
            })
            .catch(() => {})
        }
      })
    },
    // 零件选择
    openPartDialog() {
      this.showPart = true
    },
    selectPart(part) {
      if (part) {
        this.dataForm.partNo = part.partNo
        this.dataForm.partName = part.partName
        this.dataForm.partId = part.id
        this.dataForm.unit = part.unit
      }
    },
    openOperationDialog() {
      this.showOperation = true
    },
    selectOperation(operation) {
      if (operation) {
        this.dataForm.operationId = operation.id
        this.dataForm.operationName = operation.name
        this.dataForm.operationNo = operation.operationNo
      }
    },
    clearData() {
      this.dataForm.partName = null
      this.dataForm.partNo = null
      this.dataForm.partId = null
      this.dataForm.qpa = null
      this.dataForm.discNum = null
      this.dataForm.unit = null
      this.dataForm.parent = null
      this.dataForm.operationId = null
      this.dataForm.operationName = null
      this.dataForm.operationNo = null
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.clearData()
        this.$nextTick(() => {})
      }
    }
  }
}
</script>
<style>
.struct-form-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.struct-form-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.struct-form-dialog .el-dialog__body {
  padding: 5px 20px;
}

.struct-form-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.struct-form-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
